@@ -170,7 +170,7 @@ from ae.i18n import get_f_string
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
 
 
-__version__ = '0.1.34'
+__version__ = '0.1.35'
 
 
 FLOW_PATH_ROOT_ID = 'ROOT'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -227,7 +227,7 @@ def correct_item_id(item_id: str) -> str:
     return item_id.lstrip(INVALID_ITEM_ID_PREFIX_CHARS)
 
 
-def flow_path_items_from_text(text: str) -> Tuple[str, LiszNode]:
+def flow_path_items_from_text(text: str) -> Tuple[str, str, LiszNode]:
     """ parse and interpret text block for (optional) flow path text and node data (in pprint.pformat/repr format).
 
     :param text:                text block to be parsed. The text block can optionally be prefixed with a extra
@@ -242,7 +242,10 @@ def flow_path_items_from_text(text: str) -> Tuple[str, LiszNode]:
                                 * dict repr string (starting with '{' character).
                                 * list repr string (starting with '[' character).
 
-    :return:                    tuple of flow path (empty string if root or not given) and node list.
+    :return:                    tuple of
+                                error message (empty string if no error occurred),
+                                flow path (empty string if root or not given) and
+                                node list.
     """
     flow_path_text = ""
     if text.startswith('{'):
@@ -258,12 +261,14 @@ def flow_path_items_from_text(text: str) -> Tuple[str, LiszNode]:
         else:
             node_lit = "[" + ",".join("{'id': '" + line + "'}" for line in text.split("\n") if line) + "]"
 
+    parse_err_msg = ""
     try:
         node = ast.literal_eval(node_lit)
-    except (SyntaxError, ValueError):
+    except (SyntaxError, ValueError) as ex:
+        parse_err_msg = str(ex)
         node = []
 
-    return flow_path_text, node
+    return parse_err_msg, flow_path_text, node
 
 
 def item_sel_filter(item: LiszItem) -> bool:
@@ -731,9 +736,9 @@ class LiszDataMixin(ABC):
             return (node_name, list(), file_path,
                     f"import file is bigger than {IMPORT_NODE_MAX_FILE_LEN} bytes ({file_len})")
 
-        _, node = flow_path_items_from_text(file_content)   # ignore optional flow path given in 1st line
-        if not node:
-            return node_name, list(), file_path, "invalid file content or empty file"
+        err_msg, _, node = flow_path_items_from_text(file_content)   # ignore optional flow path given in 1st line
+        if err_msg or not node:
+            return node_name, list(), file_path, "invalid file content or empty file; ERR=" + err_msg
 
         if len(node) > IMPORT_NODE_MAX_ITEMS:
             return (node_name, list(), file_path,
